import axios from 'axios'

// 根据环境变量获取基础URL
const baseURL = process.env.VUE_APP_BASE_API

const api = axios.create({
  baseURL,
  timeout: 10000,  // 增加超时时间
  withCredentials: true,
  retry: 3,        // 重试次数
  retryDelay: 1000 // 重试间隔
})

// 请求拦截器
api.interceptors.request.use(
  config => {
    // 可以在这里添加loading状态
    return config
  },
  error => {
    console.error('请求错误:', error)
    return Promise.reject(error)
  }
)

// 响应拦截器
api.interceptors.response.use(
  response => response,
  async error => {
    const config = error.config;
    
    // 如果是验证码错误，并且还有重试次数
    if (error.response?.data?.code === -462 && config.retryCount < config.retry) {
      config.retryCount = config.retryCount || 0;
      config.retryCount += 1;
      
      // 延迟重试
      await new Promise(resolve => setTimeout(resolve, config.retryDelay));
      
      // 重试请求
      return api(config);
    }
    
    return Promise.reject(error);
  }
)

export default {
  // 获取推荐歌单
  getRecommendPlaylists() {
    return api.get('/personalized')
  },
  
  // 获取歌单详情
  getPlaylistDetail(id) {
    return api.get(`/playlist/detail?id=${id}`)
  },
  
  // 获取歌曲详情
  getSongDetail(id) {
    return api.get(`/song/detail?ids=${id}`)
  },
  
  // 获取歌曲 URL
  getSongUrl(id) {
    return api.get(`/song/url?id=${id}`)
  },
  
  // 搜索
  search(keywords) {
    return api.get(`/search?keywords=${keywords}`)
  },

  // 手机号登录
  loginByPhone(phone, password) {
    return api.post('/login/cellphone', {
      phone,
      password
    })
  },

  // 获取用户信息
  getUserInfo() {
    return api.get('/user/account')
  },

  // 获取用户歌单
  getUserPlaylists(uid) {
    return api.get('/user/playlist', {
      params: { uid }
    })
  },

  // 获取登录状态
  getLoginStatus() {
    return api.get('/login/status')
  },

  // 退出登录
  logout() {
    return api.get('/logout')
  },

  // 获取用户喜欢的音乐列表
  getLikedList(uid) {
    return api.get('/likelist', {
      params: { uid }
    })
  },

  // 喜欢音乐
  likeSong(id) {
    return api.get('/like', {
      params: {
        id,
        like: true
      }
    })
  },

  // 取消喜欢音乐
  unlikeSong(id) {
    return api.get('/like', {
      params: {
        id,
        like: false
      }
    })
  },

  // 获取歌词
  getLyric(id) {
    return api.get('/lyric', {
      params: { id }
    })
  },

  // 获取二维码key
  getQRKey() {
    return api.get('/login/qr/key', {
      params: {
        timestamp: new Date().getTime()
      }
    })
  },

  // 获取二维码
  getQRCode(key) {
    return api.get('/login/qr/create', {
      params: {
        key,
        qrimg: true,
        timestamp: new Date().getTime()
      }
    })
  },

  // 检查二维码状态
  checkQRStatus(key) {
    return api.get('/login/qr/check', {
      params: {
        key,
        timestamp: new Date().getTime()
      }
    })
  }
} 