import Vue from 'vue'
import Vuex from 'vuex'
import api from '../api'
import createPersistedState from 'vuex-persistedstate'

Vue.use(Vuex)

export default new Vuex.Store({
  plugins: [
    createPersistedState({
      key: 'music-player-state',
      paths: ['currentSong', 'playlist', 'playMode', 'currentIndex', 'userInfo']
    })
  ],
  state: {
    currentSong: {},
    playlist: [],
    playMode: 'sequence', // sequence, loop, random
    currentIndex: -1,
    isPlaying: false,
    isLoading: false,
    currentTime: 0,
    duration: 0,
    userInfo: null,
    userPlaylists: [],
    loginDialogVisible: false
  },
  mutations: {
    setCurrentSong(state, song) {
      state.currentSong = song || {}
    },
    setPlaylist(state, list) {
      state.playlist = list || []
    },
    setPlayMode(state, mode) {
      state.playMode = mode
    },
    setCurrentIndex(state, index) {
      state.currentIndex = index
    },
    setPlaying(state, status) {
      state.isPlaying = status
    },
    setLoading(state, status) {
      state.isLoading = status
    },
    setCurrentTime(state, time) {
      state.currentTime = time
    },
    setDuration(state, duration) {
      state.duration = duration
    },
    setUserInfo(state, info) {
      state.userInfo = info
    },
    setUserPlaylists(state, playlists) {
      state.userPlaylists = playlists
    },
    setLoginDialogVisible(state, visible) {
      state.loginDialogVisible = visible
    }
  },
  actions: {
    async restorePlayState({ commit, state }) {
      if (!state.currentSong.id) {
        return
      }

      try {
        commit('setLoading', true)
        // 重新获取歌曲信息
        const res = await Vue.prototype.$api.getSongUrl(state.currentSong.id)
        if (res.data?.data?.[0]?.url) {
          commit('setCurrentSong', {
            ...state.currentSong,
            url: res.data.data[0].url
          })
        } else {
          // 如果获取失败，清除当前歌曲
          commit('setCurrentSong', null)
          commit('setPlaying', false)
        }
      } catch (error) {
        console.error('恢复播放状态失败:', error)
        commit('setCurrentSong', null)
        commit('setPlaying', false)
      } finally {
        commit('setLoading', false)
      }
    },

    async playSong({ commit, state, dispatch }, song) {
      // 检查登录状态
      const isLoggedIn = await dispatch('checkLoginStatus')
      if (!isLoggedIn) {
        commit('setLoginDialogVisible', true)
        Vue.prototype.$message.warning('请先登录')
        return
      }

      if (state.currentSong.id === song.id) {
        commit('setPlaying', !state.isPlaying)
        return
      }

      try {
        commit('setLoading', true)
        commit('setPlaying', false)
        
        const res = await Vue.prototype.$api.getSongUrl(song.id)
        if (res?.data?.data?.[0]?.url) {
          const newSong = {
            ...song,
            url: res.data.data[0].url
          }
          
          if (!state.playlist.find(item => item.id === song.id)) {
            commit('setPlaylist', [...state.playlist, newSong])
          }
          
          commit('setCurrentSong', newSong)
          commit('setCurrentIndex', state.playlist.length - 1)
          
          setTimeout(() => {
            commit('setPlaying', true)
          }, 100)
        } else {
          throw new Error('获取歌曲链接失败')
        }
      } catch (error) {
        console.error('播放歌曲失败:', error)
        Vue.prototype.$message.error('播放失败，请重试')
        commit('setCurrentSong', {})
        commit('setPlaying', false)
      } finally {
        commit('setLoading', false)
      }
    },

    async playNext({ dispatch, state }) {
      if (state.playlist.length === 0) return
      
      const currentIndex = state.currentIndex
      let nextIndex = currentIndex + 1
      
      if (nextIndex >= state.playlist.length) {
        nextIndex = 0
      }
      
      const nextSong = state.playlist[nextIndex]
      if (nextSong) {
        await dispatch('playSong', nextSong)
      }
    },

    async playPrev({ dispatch, state }) {
      if (state.playlist.length === 0) return
      
      const currentIndex = state.currentIndex
      let prevIndex = currentIndex - 1
      
      if (prevIndex < 0) {
        prevIndex = state.playlist.length - 1
      }
      
      const prevSong = state.playlist[prevIndex]
      if (prevSong) {
        await dispatch('playSong', prevSong)
      }
    },

    async fetchPlaylist({ commit }) {
      try {
        // TODO: 实现获取播放列表的接口调用
        const list = []
        commit('setPlaylist', list)
      } catch (error) {
        console.error('获取播放列表失败:', error)
      }
    },
    async checkLoginStatus({ commit }) {
      try {
        const res = await Vue.prototype.$api.getLoginStatus()
        if (res.data.data.code === 200) {
          commit('setUserInfo', res.data.data.profile)
          return true
        }
        return false
      } catch (error) {
        console.error('检查登录状态失败:', error)
        return false
      }
    },
    async fetchUserPlaylists({ commit, state }) {
      if (!state.userInfo) return
      
      try {
        const res = await api.getUserPlaylists(state.userInfo.userId)
        if (res.data.code === 200) {
          commit('setUserPlaylists', res.data.playlist)
        }
      } catch (error) {
        console.error('获取用户歌单失败:', error)
      }
    }
  }
}) 