import musicApi from '../../api/music'
const app = getApp()

Page({
  data: {
    musicApi,
    uid: null,
    likedSongs: [],
    recentPlayed: [],
    playlists: [], // 用户歌单
    loading: false,
    currentTab: 'liked' // 当前选中的标签
  },

  async onLoad() {
    const uid = app.globalData.uid
    if (!uid) {
      try {
        const res = await app.getUserAccount()
        if (res.data.code === 200 && res.data.account?.id) {
          app.globalData.uid = res.data.account.id
          this.setData({ uid: res.data.account.id })
          await this.loadData(res.data.account.id)
        }
      } catch (error) {
        console.error('获取用户信息失败:', error)
        wx.showToast({
          title: '获取用户信息失败',
          icon: 'none'
        })
      }
    } else {
      this.setData({ uid })
      await this.loadData(uid)
    }
  },

  async loadData(uid) {
    this.setData({ loading: true })
    try {
      await Promise.all([
        this.loadLikedSongs(uid),
        this.loadRecentPlayed(uid)
      ])
    } catch (error) {
      console.error('加载数据失败:', error)
      wx.showToast({
        title: '加载失败',
        icon: 'none'
      })
    } finally {
      this.setData({ loading: false })
    }
  },

  onShow() {
    if (typeof this.getTabBar === 'function' && this.getTabBar()) {
      this.getTabBar().setData({
        selected: 2  // 我的音乐 tab 索引为 2
      })
    }
  },

  async loadLikedSongs(uid) {
    try {
      const likelistRes = await musicApi.getLikedSongs(uid)
      if (likelistRes.data.code === 200 && likelistRes.data.ids?.length > 0) {
        const detailRes = await musicApi.getSongDetail(likelistRes.data.ids)
        if (detailRes.data.code === 200) {
          this.setData({
            likedSongs: detailRes.data.songs || []
          })
        }
      }
    } catch (error) {
      console.error('获取喜欢的音乐失败:', error)
    }
  },

  async loadRecentPlayed(uid) {
    try {
      const res = await musicApi.getUserRecord(uid)
      if (res.data.code === 200) {
        const songs = res.data.weekData?.map(item => item.song) || []
        this.setData({
          recentPlayed: songs
        })
      }
    } catch (error) {
      console.error('获取最近播放失败:', error)
    }
  },

  async loadUserPlaylists(uid) {
    if (!uid) {
      console.error('loadUserPlaylists: uid is missing')
      return
    }

    try {
      console.log('开始获取歌单, uid:', uid) // 调试用
      const res = await musicApi.getUserPlaylists(uid)
      console.log('歌单响应:', res) // 调试用
      
      if (res.data.code === 200) {
        const playlists = res.data.playlist.filter(item => 
          item.userId === uid && !item.specialType
        )
        this.setData({ playlists })
      } else {
        throw new Error(res.data.msg || '获取歌单失败')
      }
    } catch (error) {
      console.error('获取用户歌单失败:', error)
      wx.showToast({
        title: '获取歌单失败',
        icon: 'none'
      })
    }
  },

  async handlePlay(e) {
    const { song } = e.detail
    if (!song || !song.id) return

    try {
      const res = await musicApi.getSongUrl(song.id)
      if (res.data.code === 200 && res.data.data && res.data.data[0]) {
        const url = res.data.data[0].url
        if (url) {
          const bgAudio = wx.getBackgroundAudioManager()
          bgAudio.title = song.name
          bgAudio.singer = song.ar?.map(a => a.name).join('/') || '未知歌手'
          bgAudio.coverImgUrl = song.al?.picUrl || ''
          bgAudio.src = url
          
          const playerBar = this.selectComponent('#player-bar')
          if (playerBar) {
            playerBar.setData({ song })
          }
        } else {
          wx.showToast({
            title: '暂无版权',
            icon: 'none'
          })
        }
      }
    } catch (error) {
      console.error('播放失败:', error)
      wx.showToast({
        title: '播放失败',
        icon: 'none'
      })
    }
  },

  onPullDownRefresh() {
    Promise.all([
      this.loadLikedSongs(this.data.uid),
      this.loadRecentPlayed(this.data.uid)
    ]).then(() => {
      wx.stopPullDownRefresh()
    })
  },

  // 切换标签
  switchTab(e) {
    const tab = e.currentTarget.dataset.tab
    this.setData({ currentTab: tab })
  },

  // 跳转到歌单详情
  goToPlaylist(e) {
    const { id } = e.currentTarget.dataset
    wx.navigateTo({
      url: `/pages/playlist/index?id=${id}`
    })
  }
}) 